summaryrefslogtreecommitdiff
path: root/src/input/inputactiondata.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/input/inputactiondata.h')
-rw-r--r--src/input/inputactiondata.h3
1 files changed, 2 insertions, 1 deletions
diff --git a/src/input/inputactiondata.h b/src/input/inputactiondata.h
index 2f5ee2ed6..cbb924070 100644
--- a/src/input/inputactiondata.h
+++ b/src/input/inputactiondata.h
@@ -54,7 +54,8 @@ namespace Input
GRP_GUI = 16, // gui key
GRP_MOVETOPOINT = 32, // move to point key
GRP_GUICHAN = 64, // for guichan based controls
- GRP_REPEAT = 128 // repeat emulation keys
+ GRP_REPEAT = 128, // repeat emulation keys
+ GRP_PET_EMOTION = 256 // pet emotions key
};
} // namespace Input